--
-- SQL script to load metadata into AMI/IM2 database
--
-- To create the tables, connect to a database
-- and run this file within an SQL interpreter.
-- For PostgreSQL, execute initdb, postmaster, createdb,
-- then connect with psql and run "\i mdDb_loader.sql"
--
-- CAUTION: this will erase existing tables with same names.

--
-- Create/load table: lang_influence
--

-- Creates temporal table 

DROP TABLE IF EXISTS lang_influence_TEMP;

CREATE TABLE lang_influence_TEMP( 
 participant_id text NOT NULL,
 language text 
 );

DROP TABLE IF EXISTS lang_influence;

CREATE TABLE lang_influence( 
 participant_id text NOT NULL,
 language text 
 );

COPY lang_influence_TEMP FROM 'D:/im2/ami2imdi-with-links/out/influence.csv' DELIMITER '|' ;
 
-- Imports non duplicated data

INSERT INTO lang_influence
SELECT DISTINCT participant_id, language
FROM lang_influence_TEMP;

DROP TABLE lang_influence_TEMP;

--ALTER TABLE ONLY segments ADD CONSTRAINT segments_pkey PRIMARY KEY ( meeting_id, speaker_id, segment_id, annotator );

--
-- Create/load table: meetings
--

DROP TABLE IF EXISTS meetings;

CREATE TABLE meetings( 
 meeting_id text NOT NULL,
 type text,
 date text,
 institution text,
 country text,
 continent text,
 starttime text,
 duration text,
 description text
);

COPY meetings FROM 'D:/im2/ami2imdi-with-links/out/meetings.csv' DELIMITER '|' ;
ALTER TABLE ONLY meetings ADD CONSTRAINT meetings_pkey PRIMARY KEY ( meeting_id);

--
-- Create/load table: participation
--

DROP TABLE IF EXISTS participation;

CREATE TABLE participation( 
 meeting_id text NOT NULL,
 participant_id text NOT NULL,
 camera text,
 channel text,
 role text
);

COPY participation FROM 'D:/im2/ami2imdi-with-links/out/participation.csv' DELIMITER '|' ;
ALTER TABLE ONLY participation ADD CONSTRAINT participation_pkey PRIMARY KEY ( meeting_id, participant_id);

--
-- Create/load table: speakers
--

DROP TABLE IF EXISTS speakers;

CREATE TABLE speakers( 
 participant_id text NOT NULL,
 age text,
 sex text,
 native_lang text,
 country_eng text,
 region_eng text,
 months_eng text
);

DROP TABLE IF EXISTS speakers_TEMP;


-- Creates temporal table 

CREATE TABLE speakers_TEMP( 
 participant_id text NOT NULL,
 age text,
 sex text,
 native_lang text,
 country_eng text,
 region_eng text,
 months_eng text
);

COPY speakers_TEMP FROM 'D:/im2/ami2imdi-with-links/out/speakers.csv' DELIMITER '|' ;

-- Imports non duplicated data

INSERT INTO speakers
SELECT DISTINCT participant_id, age, sex, native_lang, country_eng, region_eng, months_eng
FROM speakers_TEMP;

DROP TABLE speakers_TEMP;

ALTER TABLE ONLY speakers ADD CONSTRAINT speakers_pkey PRIMARY KEY ( participant_id);

--
-- Create/load table: resources
--

DROP TABLE IF EXISTS resources;
-- agregar participant_id
CREATE TABLE resources( 
 -- resource_id SERIAL,
 meeting_id text NOT NULL,
 resource_id text NOT NULL,
 url text,
 type text,
 format text,
 size text,
 channel text,
 source text,
 source_nr text,
page_nr text,
date text
);

COPY resources FROM 'D:/im2/ami2imdi-with-links/out/resources.csv' DELIMITER '|' ;
ALTER TABLE ONLY resources ADD CONSTRAINT resources_pkey PRIMARY KEY ( meeting_id, resource_id);

