<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:nite="http://nite.sourceforge.net/"
xmlns:xsi="http://www.mpi.nl/IMDI/Schema/IMDI ./IMDI_3.0.xsd">
<!--	
		Description:  applying this stylesheet to the annotation file meetings.xml,
							  it generates one .imdi file per meeting adding
							  data from crawler's output file (logFile parameter) and
							  annotation file participants.xml (partFile parameter)
		Parameters : logFile = output generated by crawler.pl ; provided example
							 file ami_file_list.xml could be used
							 partFile = file with additional data about participants ;
                             provided with the annotations for the corpus,
                             usually annotations\corpusResources\participants.xml
							 outputDir = folder where the imdi files will be created (including
                             final slash), by default they will be created
                             in the current directory
		Usage example: > java -jar saxon8.jar -t D:/annotations/corpusResources/meetings.xml
									ami2imdi.xslt  logFile="log.xml" partFile="D:/annotations/corpusResources/participants.xml"
									outputDir="imdi-structure/"
		Remarks:		- If the parameters logFile and partFile are not provided (in the
							command line or here), the script will abort
							- depending on the processor used, paths may have / or \ 

		Author: 	Paula Estrella - ISSCO/UniGe - February 2007
		
-->
	<xsl:output method="xml" indent="yes"/>
	<!--xsl:param name="partFile" select="'D:/annotations/corpusResources/participants.xml'"/-->
	<xsl:param name="partFile" select="''"/>
	<xsl:param name="logFile" select="''"/><!-- -->
	<xsl:param name="outputDir" select="''"/>
	<xsl:template match="nite:root">
		<xsl:choose>
			<xsl:when test="$partFile != '' and $logFile !=''">
			</xsl:when>
			<xsl:otherwise>
				<xsl:message terminate="yes">
					<xsl:text>MISSING: parameter "partFile" (e.g. annotations\corpusResources\participants.xml ) 
					or "logFile" (e.g. ami_file_list.xml) </xsl:text>
				</xsl:message>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates mode="txt"/>
	</xsl:template>
	<xsl:template match="meeting" mode="txt">
		<xsl:result-document  href="{$outputDir}{@observation}.imdi" indent="yes">
		<METATRANSCRIPT Date="16-02-2007" FormatId="IMDI 3.0" Type="SESSION" Version="16" xsi:schemaLocation="http://www.mpi.nl/IMDI/Schema/IMDI ./IMDI_3.0.xsd">
		<xsl:comment>
			File automatically generated by ami2imdi.xslt - Paula Estrella, ISSCO/UniGe, February 2007
		</xsl:comment>
			<xsl:variable name="name" select="./@observation"/>
				<Session>
					<Name>					
						<xsl:value-of select="$name"/>
					</Name>
					<Title>
						<xsl:value-of select="@name"/>
					</Title>
					<Date>
						<xsl:value-of select="@dateOnly"/>
					</Date>
					<MDGroup>
						<xsl:apply-templates select="$name"/>
							<Project>
								<Name> AMI Meeting Corpus</Name>
								<Title> Augmented Multi-party Interaction </Title>
								<Id>AMI/IM2</Id>
							<Contact>
								<Name>  </Name>
								<Address/>
								<Email>  http://www.idiap.ch/amicorpus/contact </Email>
								<Organisation/>
							</Contact>
						</Project>						
						<xsl:apply-templates select="@dateOnly"/>
						<xsl:apply-templates select="./@type"/>
						<Actors>
							<Description LanguageId="" Link=""/>
							<xsl:apply-templates select="speaker"/>
						</Actors>
					</MDGroup>
					<Resources>
					<xsl:apply-templates select="document($logFile)//meeting[@id=$name]//leaf"  mode="media">
						<xsl:sort select="@format" order="ascending"/>
					</xsl:apply-templates>
					<xsl:apply-templates select="document($logFile)//meeting[@id=$name]//leaf"  mode="written">
						<xsl:sort select="@format" order="ascending"/>
					</xsl:apply-templates>
					</Resources>
					<Anonyms>
                <ResourceLink/>
                <Access>
                    <Availability Type="OpenVocabulary"/>
                    <Date>Unspecified</Date>
                    <Owner/>
                    <Publisher/>
                    <Contact>
                        <Name/>
                        <Address/>
                        <Email/>
                        <Organisation/>
                    </Contact>
                    <Description LanguageId="" Link=""/>
                </Access>
            </Anonyms>
					<References>
						<Description LanguageId="ISO639-2:eng" Link="">
								Carletta, J. (2006) Announcing the AMI Meeting Corpus. The ELRA Newsletter 11(1), January-March, p. 3-5.
						</Description>
					</References>		
				</Session>				
			</METATRANSCRIPT>		
		</xsl:result-document>
	</xsl:template>
	
	<xsl:template match="@observation">
		<Location>
			<Continent Link="http://www.mpi.nl/IMDI/Schema/Continents.xml" Type="ClosedVocabulary">Europe</Continent>
			<Country Link="http://www.mpi.nl/IMDI/Schema/Countries.xml" Type="ClosedVocabulary">
				<xsl:choose>
					<xsl:when test="starts-with(.,'I')">
						<xsl:text>Switzerland</xsl:text>
					</xsl:when>
					<xsl:when test="starts-with(.,'E')">
						<xsl:text>United Kingdom</xsl:text>
					</xsl:when>
					<xsl:when test="starts-with(.,'T')">
						<xsl:text>Netherlands</xsl:text>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>				
			</Country>
			<Address>
				<xsl:choose>
					<xsl:when test="starts-with(.,'I')">
						<xsl:text>IDIAP/ISSCO</xsl:text>
					</xsl:when>
					<xsl:when test="starts-with(.,'E')">
						<xsl:text>University of Edinburgh</xsl:text>
					</xsl:when>
					<xsl:when test="starts-with(.,'T')">
						<xsl:text>TNO</xsl:text>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</Address>
		</Location>
	</xsl:template>
	<xsl:template match="@dateOnly">
		<Keys>			
			<Key Name="StartTime" Type="OpenVocabulary">
				<xsl:value-of select="../@startTime"/>
			</Key>
			<Key Name="Duration" Type="OpenVocabulary">
				<xsl:value-of select="../@duration"/>
			</Key>
		</Keys>
	</xsl:template>
	<xsl:template match="@type">
		<Content>
			<Genre Link="http://www.mpi.nl/IMDI/Schema/Content-Genre.xml" Type="OpenVocabulary">Interactive Discourse</Genre>
			<SubGenre DefaultLink="" Link="http://www.mpi.nl/IMDI/Schema/Content-SubGenre.xml" Type="OpenVocabularyList">
						meetings
            </SubGenre>
			<Task Link="http://www.mpi.nl/IMDI/Schema/Content-Task.xml" Type="OpenVocabulary">
            </Task>
			<Modalities Link="http://www.mpi.nl/IMDI/Schema/Content-Modalities.xml" Type="OpenVocabularyList">
						multimodal
            </Modalities>
			<Subject DefaultLink="" Link="http://www.mpi.nl/IMDI/Schema/Content-Subject.xml" Type="OpenVocabularyList">
			</Subject>
			<CommunicationContext>
				<Interactivity Link="http://www.mpi.nl/IMDI/Schema/Content-Interactivity.xml" >
								interactive
				</Interactivity>
				<PlanningType Link="http://www.mpi.nl/IMDI/Schema/Content-PlanningType.xml" Type="ClosedVocabulary">
							semi-spontaneous
				</PlanningType>
				<Involvement Link="http://www.mpi.nl/IMDI/Schema/Content-Involvement.xml" Type="ClosedVocabulary">
                </Involvement>
				<SocialContext Link="http://www.mpi.nl/IMDI/Schema/Content-SocialContext.xml" Type="ClosedVocabulary">
							Controlled environment
				</SocialContext>
				<EventStructure Link="http://www.mpi.nl/IMDI/Schema/Content-EventStructure.xml" Type="ClosedVocabulary">
							Conversation
				</EventStructure>
				<Channel Link="http://www.mpi.nl/IMDI/Schema/Content-Channel.xml" Type="ClosedVocabulary">
							Experimental setting
				</Channel>
			</CommunicationContext>
			<Description LanguageId="ISO639-2:eng" Link="">
				<xsl:variable name="name" select="../@observation"/>
				<xsl:if test=".='scenario'">
					<xsl:choose>
						<xsl:when test="ends-with($name,'a')">
							<xsl:text>Project kick-off, consisting of building a project team and getting acquainted with each other and the task.</xsl:text>
						</xsl:when>
						<xsl:when test="ends-with($name,'b')">
							<xsl:text> Functional design, in which the team sets the user requirements, the technical functionality, and the working design.</xsl:text>
						</xsl:when>
						<xsl:when test="ends-with($name,'c')">
							<xsl:text>Conceptual design, in which the team determines the conceptual specification for the components, properties, and materials to be used in the apparatus, as well as the user interface.</xsl:text>
						</xsl:when>
						<xsl:when test="ends-with($name,'d')">
							<xsl:text>Detailed design, which finalizes the look-and-feel and user interface, and in which the result is evaluated</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>AMI scenario meeting</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:if test=".='nonscenario'">
					<xsl:value-of select="../@topic"/>
				</xsl:if>
			</Description>
		</Content>
	</xsl:template>
	<xsl:template match="speaker">
		<xsl:variable name="participants" select="document($partFile)"/>
		<xsl:variable name="name" select="@global_name"/>
		<Actor> 
		<ResourceRef/>
			<Role Link="http://www.mpi.nl/IMDI/Schema/Actor-Role.xml" Type="OpenVocabularyList">
				<xsl:choose>
					<xsl:when test="@role='PM'">
						<xsl:text>Project Manager</xsl:text>
					</xsl:when>
					<xsl:when test="@role='ID'">
						<xsl:text>Industrial Designer</xsl:text>
					</xsl:when>
					<xsl:when test="@role='ME'">
						<xsl:text>Marketing Expert</xsl:text>
					</xsl:when>
					<xsl:when test="@role='UI'">
						<xsl:text>User Interface Designer</xsl:text>
					</xsl:when>					
					<xsl:otherwise>
						<xsl:text>Unspecified</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</Role>
			<Name>
				<xsl:value-of select="$name"/>
			</Name>
			<FullName/>
			<Code>
				<xsl:value-of select="$name"/>
			</Code>
			<FamilySocialRole Link="http://www.mpi.nl/IMDI/Schema/Actor-FamilySocialRole.xml" Type="OpenVocabularyList"/>
			<Languages>
				<Description LanguageId="" Link=""/>
				<Language>
					<Id/>					
					<xsl:choose>
						<xsl:when test="$participants//participant[@nite:id=$name]//@native_language">
							<Name Link="http://www.mpi.nl/IMDI/Schema/MPI-Languages.xml" Type="OpenVocabulary">
								<xsl:value-of select="$participants//participant[@nite:id=$name]//@native_language"/>	
							</Name>
							<MotherTongue>true</MotherTongue>					
						</xsl:when>
						<xsl:otherwise>
						<Name Link="http://www.mpi.nl/IMDI/Schema/MPI-Languages.xml" Type="OpenVocabulary">Unspecified</Name>
							<MotherTongue>Unspecified</MotherTongue>				
						</xsl:otherwise>
					</xsl:choose>				
					<PrimaryLanguage>
						<xsl:value-of select="@english_language"/>
					</PrimaryLanguage>
					<Description LanguageId="" Link=""/> 					
				</Language>
				<xsl:if test="$participants//participant[@nite:id=$name]//english_language//influence">
					<xsl:apply-templates select="$participants//participant[@nite:id=$name]/english_language//influence"/>
				</xsl:if>
			</Languages>
			<EthnicGroup Type="OpenVocabulary"/>
			<Age>
				<xsl:value-of select="$participants//participant[@nite:id=$name]//@age_at_collection"/>
			</Age>
			<BirthDate>Unspecified</BirthDate>
			<Sex Link="http://www.mpi.nl/IMDI/Schema/Actor-Sex.xml" Type="ClosedVocabulary">
				<xsl:choose>
					<xsl:when test="$participants//participant[@nite:id=$name]//@sex='M'">
						<xsl:text>Male</xsl:text>
					</xsl:when>
					<xsl:when test="$participants//participant[@nite:id=$name]//@sex='F'">
						<xsl:text>Female</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>Unspecified</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</Sex>
			<Education>Unspecified</Education>
			<Anonymized>
				<xsl:text>true</xsl:text>
			</Anonymized>
			<Contact>
				<Name/>
				<Address/>
				<Email/>
				<Organisation/>
			</Contact>
			<Keys>
				<xsl:if test="$participants//participant[@nite:id=$name]//english_language//@country">	
					<Key Name="Country_English_influence" Type="OpenVocabulary">
						<xsl:value-of select="$participants//participant[@nite:id=$name]//english_language//@country"/>
					</Key>					
				</xsl:if> 
				<xsl:if test="$participants//participant[@nite:id=$name]//english_language//@region">	
					<Key Name="Region_English_influence" Type="OpenVocabulary">
						<xsl:value-of select="$participants//participant[@nite:id=$name]//english_language//@region"/>
					</Key>					
				</xsl:if> 
				<xsl:if test="$participants//participant[@nite:id=$name]//english_language//@months">	
					<Key Name="Months_English_practice" Type="OpenVocabulary">
						<xsl:value-of select="$participants//participant[@nite:id=$name]//english_language//@months"/>
					</Key>					
				</xsl:if> 
				<Key Name="channel" Type="OpenVocabulary">
					 <xsl:value-of select="@channel"/>
				</Key>
				<Key Name="camera" Type="OpenVocabulary">
					 <xsl:value-of select="@camera"/>
				</Key>				
				<xsl:variable name="meetId" select="../@observation"/>
				<xsl:variable name="log" select="document($logFile)"/>
				<xsl:variable name="channel" select="./@channel"/>				
				<xsl:for-each select="$log//meeting[@id=$meetId]//leaf[number(@channel)=($channel + 1) and @source='Array']">
				<Key Name="Related Audio File ">
					<xsl:value-of select="replace(.,'\n','')"/>
				</Key>
				</xsl:for-each>	
				<xsl:for-each select="$log//meeting[@id=$meetId]//leaf[@channel=$channel and @source='Headset']">
				<Key Name="Related Audio File ">
					<xsl:value-of select="replace(.,'\n','')"/>
				</Key>
				</xsl:for-each>
				<xsl:for-each select="$log//meeting[@id=$meetId]//leaf[@channel=$channel and @source='Lapel']">
				<Key Name="Related Audio File ">
					<xsl:value-of select="replace(.,'\n','')"/>
				</Key>	
				</xsl:for-each>				
				<xsl:for-each select="$log//meeting[@id=$meetId]//node[@media='video']//leaf[number(@channel)=($channel + 1)]">
				<Key Name="Related Video File ">
					<xsl:value-of select="replace(.,'\n','')"/>
				</Key>
				</xsl:for-each>				
				<xsl:for-each select="$log//meeting[@id=$meetId]//node[@media='pens']//leaf[number(@channel)=($channel + 1)]">
				<Key Name="Other Related File  ">
					<xsl:value-of select="replace(.,'\n','')"/>
				</Key> 
				</xsl:for-each>	
				<xsl:for-each select="$log//meeting[@id=$meetId]//node[@media='browsable']//leaf[@channel=$channel and @type='speakerseg']">
				<Key Name="Other Related File  ">
					<xsl:value-of select="replace(.,'\n','')"/>
				</Key> 
				</xsl:for-each>				
				</Keys>
			<Description LanguageId="" Link=""/>
		</Actor>
	</xsl:template>
	
<xsl:template match="influence">
      <Language>
		<Id/>
		<Name Link="http://www.mpi.nl/IMDI/Schema/MPI-Languages.xml" Type="OpenVocabulary"> <xsl:value-of select="@name"/></Name>
		<MotherTongue>false</MotherTongue>
		<!--PrimaryLanguage/-->			
	</Language>
</xsl:template>

	<xsl:template match="node" mode="media">
		<xsl:apply-templates select="leaf" mode="media">
			<xsl:sort select="@format"/>		
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template match="node" mode="written">
		<xsl:apply-templates select="leaf" mode="written"/>
	</xsl:template>	
	
	<xsl:template match="leaf" mode="media">
		<xsl:if test=".//@format!='text/xml' and .//@format!='text/plain' and .//@format!='text/html'">			
			<MediaFile >
			<xsl:attribute name="ResourceId">
				 <xsl:number value="position()"/>
			 </xsl:attribute>
                <ResourceLink><xsl:value-of select="concat(@url,replace(.,'\n',''))"/></ResourceLink>
                <Type Link="http://www.mpi.nl/IMDI/Schema/MediaFile-Type.xml" Type="ClosedVocabulary">
					<xsl:apply-templates select="@media"/>
                </Type>
                <Format Link="http://www.mpi.nl/IMDI/Schema/MediaFile-Format.xml" Type="OpenVocabulary"><xsl:value-of select="@format"/></Format>
                <Size><xsl:value-of select="@size"/> </Size>
                <Quality>Unspecified</Quality>
                <RecordingConditions/>
                <TimePosition>
                    <Start>						
						<xsl:value-of select="@start_time"/>
					</Start>
                    <End>
						<xsl:value-of select="@end_time"/>
                    </End>
                </TimePosition>
                 <Access>
                    <Availability Type="OpenVocabulary">
						AMI Meeting Corpus license, very similar to the  Creative Commons Attribution NonCommercial ShareAlike 2.5 License.
                    </Availability>
                    <Date>Unspecified</Date>
                    <Owner>AMI project</Owner>
                    <Publisher/>
                    <Contact>
                        <Name/>
                        <Address/>
                        <Email>
							http://corpus.amiproject.org/contact-info
                        </Email>
                        <Organisation/>
                    </Contact>
                     <Description LanguageId="" Link="">
						 To access AMI corpus, login or register at for free at http://corpus.amiproject.org/amicorpus/join_form and go to "Access AMI corpus" section of the menu. 
						 </Description>
                </Access>
                <Description LanguageId="" Link=""/>
                <Keys>
					<Key Name="Last_Modified" Type="OpenVocabulary">
						<xsl:value-of select="@last_modif"/>
					</Key>
					<xsl:if test="@page and @page!=''">
						<Key Name="Page_Nr" Type="OpenVocabulary">
							<xsl:value-of select="@page"/>
						</Key>
					</xsl:if>
					<xsl:if test="@channel and @channel!=''">
						<Key Name="Channel" Type="OpenVocabulary">
							<xsl:value-of select="@channel"/>
						</Key>
					</xsl:if>
					<xsl:if test="@source and @source!=''">
						<Key Name="Source" Type="OpenVocabulary">
							<xsl:value-of select="@source"/>
						</Key>
					</xsl:if>
					<xsl:if test="@src_nr and @src_nr!=''"> 
						<Key Name="Source_Nr" Type="OpenVocabulary">
							<xsl:value-of select="@src_nr"/>
						</Key>
					</xsl:if>
					<xsl:if test="@type and @type!=''"> 
						<Key Name="Type" Type="OpenVocabulary">
							<xsl:value-of select="@type"/>
						</Key>
					</xsl:if>
					<!--xsl:if test="@page and @page!=''"> 
						<Key Name="Type" Type="OpenVocabulary">
							<xsl:value-of select="@page"/>
						</Key>
					</xsl:if-->
					<xsl:if test="@date and @date!=''"> 
						<Key Name="Date" Type="OpenVocabulary">
							<xsl:value-of select="@date"/>
						</Key>
					</xsl:if>
                </Keys>
            </MediaFile>			
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="leaf" mode="written">
		<xsl:if test="contains(@format,'text')">		
			 <WrittenResource >
			 <xsl:attribute name="ResourceId">
				 <xsl:number value="position()"/>
			 </xsl:attribute>
                <ResourceLink><xsl:value-of select="concat(@url, replace(.,'\n',''))"/></ResourceLink>
                <MediaResourceLink/>
                <Date>Unspecified</Date>
                <Type Link="http://www.mpi.nl/IMDI/Schema/WrittenResource-Type.xml" Type="OpenVocabulary">
					<xsl:value-of select="@media"/>
                </Type>
                <SubType DefaultLink="" Link="http://www.mpi.nl/IMDI/Schema/WrittenResource-SubType-Annotation.xml" Type="OpenVocabularyList">
					Unspecified
                </SubType>
                <Format Link="http://www.mpi.nl/IMDI/Schema/WrittenResource-Format.xml" Type="OpenVocabulary">
					<xsl:value-of select="@format"/>
                </Format>
                <Size><xsl:value-of select="@size"/> </Size>
                <Validation>
                    <Type Link="http://www.mpi.nl/IMDI/Schema/Validation-Type.xml" Type="ClosedVocabulary">Formal</Type>
                    <Methodology Link="http://www.mpi.nl/IMDI/Schema/Validation-Methodology.xml" Type="ClosedVocabulary">Hand</Methodology>
                    <Level>Unspecified</Level>
                    <Description LanguageId="" Link=""/>
                </Validation>
                <Derivation Link="http://www.mpi.nl/IMDI/Schema/WrittenResource-Derivation.xml" Type="ClosedVocabulary">Unspecified</Derivation>
                <CharacterEncoding/>
                <ContentEncoding/>
                <LanguageId Type="OpenVocabulary"/>
                <Anonymized>true</Anonymized>
                <Access>
                    <Availability Type="OpenVocabulary">
						AMI Meeting Corpus license, very similar to the  Creative Commons Attribution NonCommercial ShareAlike 2.5 License.
					</Availability>
                    <Date>Unspecified</Date>
                    <Owner>AMI project</Owner>
                    <Publisher/>
                    <Contact>
                        <Name/>
                        <Address/>
                        <Email>
							http://corpus.amiproject.org/contact-info
                        </Email>
                        <Organisation/>
                    </Contact>
                    <Description LanguageId="" Link="">
						To access AMI corpus, login or register at for free at http://corpus.amiproject.org/amicorpus/join_form and go to "Access AMI corpus" section of the menu.
					</Description>
                </Access>
                <Description LanguageId="" Link=""/>
                 <Keys Name="Last_Modified" Type="OpenVocabulary">
					 <xsl:value-of select="@last_modif"/> 
                 </Keys>
                 <Keys Name="Size" Type="OpenVocabulary">
					 <xsl:value-of select="@size"/> 
				</Keys>
                 <xsl:if test="@type and @type!=''">
					 <Keys Name="Text_Type" Type="OpenVocabulary">
						 <xsl:value-of select="@type"/>
					 </Keys>
                 </xsl:if>
                 <xsl:if test="@channel and @channel!=''">
					 <Keys Name="Channel" Type="OpenVocabulary">
						 <xsl:value-of select="@channel"/>
					 </Keys>
                 </xsl:if>
            </WrittenResource>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
