#!/usr/bin/Perl 
#===============================================================================
# Description : given the (correct) URL to the ami corpus, this crawler gets
#               page contents and processes it to output an xml file
#               containing a mapping of the online corpus' structure with 
#               additional info for later use. See readme.txt for more details.
# Remarks: this script was developed to crawl a specific *private* URL, so it's
#           not coded within the script
# Usage example: perl crawler.pl output.xml http://ami.corpus-root.ch
# Author: Paula Estrella - ISSCO/ETI/UniGe
# Date: February 2007
#===============================================================================

use LWP::Simple;
use HTML::LinkExtor;

my $log = $#ARGV!=1?  die "ERROR -- Usage: perl crawler.pl <output file> <root crawling url>\n":$ARGV[0];
my $URL = $#ARGV!=1?  die "ERROR -- Usage: perl crawler.pl <output file> <root crawling url>\n":$ARGV[1];

my %formats = ('xml' => ['text/xml', 'text'],
                'jpeg' => ['image/jpeg', 'image'],
                'jpg' => ['image/jpg', 'image'],
                'gif' => ['image/gif', 'image'],
                'zip' => ['application/zip', 'document'],
                'wav' => ['audio/x-wav', 'audio'],
                'rm' => ['audio/x-rm', 'audio'],
                'smil' => ['application/smil+xml', 'document'],
                'pen' => ['application/xml', 'document'],
                'avi' => ['video/x-msvideo', 'video'],
                'txt' => ['text/plain', 'text'],
                'html' => ['text/html', 'text'],
                'htm' => ['text/html', 'text'],
                'doc' => ['application/msword', 'document'],
                'ppt' => ['application/vnd.ms-powerpoint', 'document'],
                'xls' => ['application/vnd.ms-excel', 'document'],
                'doc' => ['application/msword', 'document'],
                'lnk' => ['Unknown', 'Unknown'],
                'db' => ['Unknown', 'Unknown'],
                'mde' => ['Unknown', 'Unknown'],
                'rdp' => ['Unknown', 'Unknown'],
                'ini' => ['Unknown', 'Unknown'],
                '' => ['Unknown', 'Unknown']);

open(LOG, ">$log");
print LOG "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
print LOG "<!-- File automatically generated by crawler.pl - Paula Estrella - ISSCO/ETI/UniGe, Feb. '07 -->\n";
print LOG "<root baseURL=\"$URL\">\n";
crawl($URL);
print LOG "</root>";
my $meetId="";
my $curDir = "";
close LOG;
print STDOUT "Done.\n";
#=========================

sub crawl{
my ($url) = @_ ;

my $content = get($url);
if (!defined $content){
  die "FAILED to get page $url \n Check the provided URL";
}else{
my $parser = HTML::LinkExtor->new(); 
$parser->parse($content); 
my @links = $parser->links;

my %info=getSize($content);

@links = grep {$$_[0]=~/a/i} @links;
@links = @links[5..$#links];

foreach my $link (@links) {
  if($$link[2]=~/.*\/$/){
    $$link[2]=~s/\/$//;
    if($$link[2]=~/^[E|T|I]/){
      $meetId=$$link[2];
      print LOG "<meeting id=\"$meetId\">\n";
    }else{
      print LOG "<node media=\"$$link[2]\">\n";
      $curDir = $$link[2];
    }
      if($$link[2] eq "slides"){
        crawl($url.$$link[2]."/left.html");
      }else{
        crawl($url.$$link[2]."/");
      }
      
     if($$link[2]=~/^[E|T|I]/){
      print LOG "</meeting>\n";
    }else{
      print LOG "</node>\n";
      $curDir="";
    }

    }else{
        if($curDir eq "audio" || $curDir eq "video"){
          my ($src, $srcNr, $channel, $format, $media) = audio($$link[2]);
          print LOG "<leaf source=\"$src\" src_nr=\"$srcNr\" channel=\"$channel\" format=\"$format\" media=\"$media\" url=\"$URL$meetId/$curDir/\" size=\"$info{$$link[2]}[2]\" last_modif=\"$info{$$link[2]}[0]\">\n";
          print LOG "$$link[2]\n";
        }elsif($curDir eq "browsable"){
          my ($type, $channel, $format, $media) = browsable($$link[2]);
          print LOG "<leaf type=\"$type\" channel=\"$channel\" format=\"$format\" media=\"$media\" url=\"$URL$meetId/$curDir/\" size=\"$info{$$link[2]}[2]\" last_modif=\"$info{$$link[2]}[0]\">\n";
          print LOG "$$link[2]\n";
        }elsif($curDir eq "pens"){
          my ($page, $channel, $date, $format, $media) = pens($$link[2]);
          print LOG "<leaf page=\"$page\" channel=\"$channel\" date=\"$date\" format=\"$format\" media=\"$media\" url=\"$URL$meetId/$curDir/\" size=\"$info{$$link[2]}[2]\" last_modif=\"$info{$$link[2]}[0]\">\n";
          print LOG "$$link[2]\n";
        }elsif($curDir=~/slides/){
          my ($sTime, $eTime, $format, $media) = slides($$link[2], $URL);
          $$link[2]=~s/$URL$meetId\/$curDir\///;
          print LOG "<leaf start_time=\"$sTime\" end_time=\"$eTime\" format=\"$format\" media=\"$media\" url=\"$URL$meetId/$curDir/\" size=\"$info{$$link[2]}[2]\" last_modif=\"$info{$$link[2]}[0]\">\n";
          print LOG "$$link[2]\n";
        }else{
          my @parts=split(/\./, $$link[2]);
          my ($format, $media) = ($formats{$parts[-1]}) ? ($formats{$parts[-1]}[0],$formats{$parts[-1]}[1]) : ($formats{''}[0], $formats{''}[1]);
          print LOG "<leaf format=\"$format\" media=\"$media\" url=\"$URL$meetId/$curDir/\" size=\"$info{$$link[2]}[2]\" last_modif=\"$info{$$link[2]}[0]\">\n";
          print LOG "$$link[2]\n";
        } 
         print LOG "</leaf>\n";
    }
}
}
}

sub getSize{
my %hash =  map {$_ =~/^<IMG\s*(.*?)HREF=\"(.*?)\".*?\/A>\s*(.*)/ ? map {$_->[0] => $_->[1]} [$2,$3]:()} (split("\n",$_[0]));

foreach $e (keys %hash){
$hash{$e}=[split(" ", $hash{$e})];
}

return %hash;
}

sub slides{
my ($sTime, @parts) = split(/__/, $_[0]);
my $base = $_[1];
$sTime=~s/$base$meetId\/$curDir\/$meetId\.//;
@parts=split(/\./, $parts[0]);
return ($sTime, "$parts[0].$parts[1]",($formats{$parts[-1]}) ? ($formats{$parts[-1]}[0],$formats{$parts[-1]}[1]) : ($formats{''}[0], $formats{''}[1]));
}

sub pens{
my $args= $_[0];
my $date;
my $channel;

  my @parts = split(/Page/,$args);
  my $page =substr($parts[1],0,3);

  $channel = $args=~/\.p(en)?_?(\d)[_|.|-]/i ? $2 :();
  $date = $args=~/(\d\d)[-|.](\d\d)[-|.](\d\d\d\d)/?"$1-$2-$3":"";
  @parts=split(/\./, $args);

 return ($page, $channel, $date, ($formats{$parts[-1]}) ? ($formats{$parts[-1]}[0],$formats{$parts[-1]}[1]) : ($formats{''}[0], $formats{''}[1]));
}

sub audio{
 my @parts = split(/\./,$_[0]);
          my @src = split(/-/, $parts[1]);
          my $src="";
          my $srcNr="";
          my $channel="";
      if($src[0] =~ /[0-9]/ ){
        if($src[1] =~ /[0-9]/){
               $channel=$src[1];
               $channel=~s/0(\d)?/$1/;
               $srcNr=chop($src[0]);
               $src=$src[0];
        }else{
              $channel= $src[0]=~/(\d+)/g? $1 : chop($src[0]);
              $src="$src[0] $src[1]";
              $src=~s/$1//;
        }
          }else{
            if($src[1] =~ /[0-9]/){
                $src=$src[0];
                $channel=$src[1];
            }else{
                $src=$parts[1];
            }

          }
          return($src, $srcNr, $channel, ($formats{$parts[-1]}) ? ($formats{$parts[-1]}[0],$formats{$parts[-1]}[1]) : ($formats{''}[0], $formats{''}[1]));
}

sub browsable{
          my @parts = split(/\./,$_[0]);
          my $type=$parts[2]=~/smil/? $parts[1]:"speakerseg";
          my $channel=substr($parts[1], length($parts[1])-1)=~/[0-9]/?chop($parts[1]):"";
          return($type, $channel, ($formats{$parts[-1]}) ? ($formats{$parts[-1]}[0],$formats{$parts[-1]}[1]) : ($formats{''}[0], $formats{''}[1]));
}


