<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:nite="http://nite.sourceforge.net/"
xmlns:xsi="http://www.mpi.nl/IMDI/Schema/IMDI ./IMDI_3.0.xsd">
<!--	
Description: this stylesheet opns only once every .imdi file in a given directory, extracting the metadata and 
outputs one line with the information corresponding to each of the .csv generated by the caller script. One line
looks like this: <meeting info>@@@<participation>@@@<speakers>@@@<influence>@@@<resources>   

1- Meetings: (meet_id, place, date, start, end, duration, type, description)
2- Participation: (meet_id, speaker_id, role, camera, channel)
3- Speakers: (speaker_id, sex, age, native_lang, eng_region, eng_country, eng_months) 
4- Influence_english: (speaker_id, language)
5- Media files: (meet_id, resource_id, uri, format, media, size, [src_nr, source, channel, page, date])	
  
Usage: java -jar saxon8.jar file.imdi imdi2db.xslt

Author: 	Paula Estrella - ISSCO/UniGe - May 2007		

-->
	<xsl:output method="text" indent="yes"/>
	
	<xsl:template match="METATRANSCRIPT">
		<!-- if the imdi file contains a <Corpus> tag, we ignore it-->
		<xsl:if test=".//Corpus">
				<xsl:message terminate="yes"/>
		</xsl:if>
		<xsl:apply-templates select="Session/Name|//Location|Session/Date|Session/Title|//MDGroup/Keys|//Content/Description"/>
		<xsl:apply-templates select="//Actors"/>
		<xsl:apply-templates select="//Resources/MediaFile|//Resources/WrittenResource"/>
	</xsl:template>
	
	<xsl:template match="MDGroup/Keys">
	<xsl:choose>
		<xsl:when test="./Key[@Name='StartTime'] != ''">
			<xsl:value-of  select="./Key[@Name='StartTime']"/> <xsl:text>|</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>|</xsl:text><!-- Not specified -->
		</xsl:otherwise>
	</xsl:choose>
		<xsl:choose>
		<xsl:when test="./Key[@Name='Duration'] != ''">
			<xsl:value-of  select="./Key[@Name='Duration']"/> <xsl:text>|</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>|</xsl:text><!-- Not specified -->
		</xsl:otherwise>
	</xsl:choose>	
	</xsl:template>
	
	<xsl:template match="Actor/Keys">
		<xsl:value-of  select="./Key[@Name='camera']"/> <xsl:text>|</xsl:text>
		<xsl:value-of  select="./Key[@Name='channel']"/> <xsl:text>|</xsl:text>
	</xsl:template>
	
<xsl:template match="Actors">
	<xsl:for-each select="./Actor">
		<xsl:call-template name="participation"/>
	</xsl:for-each>
		<xsl:text>@@@</xsl:text>
		<xsl:for-each select="./Actor">
			<xsl:apply-templates  select="./Name|./Sex|./Age"/>   
			<xsl:value-of select="normalize-space(.//Language[position()=1]/Name)"/> <xsl:text>|</xsl:text>
			<xsl:call-template name="keysLang"/><xsl:text>
</xsl:text>
		</xsl:for-each>
		<xsl:text>@@@</xsl:text>
			<xsl:choose>
				<xsl:when test=".//Language[position()>1]">
					<xsl:for-each select="./Actor">
						<!--xsl:if test=".//Language[position()>1]"-->
							<xsl:call-template name="langInfluence"/>
						<!--/xsl:if-->	
					</xsl:for-each>					
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>NO </xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		<xsl:text>@@@</xsl:text>		
</xsl:template>

<xsl:template name="langInfluence">	
	<xsl:variable name="code"  select="./Code"/> 		
			<xsl:for-each select=".//Language[position()>1]">
				<xsl:value-of  select="normalize-space($code)"/> <xsl:text>|</xsl:text> 
				<xsl:value-of select="normalize-space(./Name)"/><xsl:text>
</xsl:text> 
			</xsl:for-each>	
</xsl:template>

<xsl:template name="participation">
	<xsl:value-of  select="//Session/Name"/><xsl:text>|</xsl:text>
	<xsl:apply-templates  select="./Name"/> 
	<xsl:apply-templates select="./Keys"/> 
	<xsl:apply-templates select="./Role"/>
</xsl:template>

	<xsl:template match="Name|Date|Sex|Age">
			<xsl:value-of  select="."/> <xsl:text>|</xsl:text>
	</xsl:template>
		
	<xsl:template match="Description">
			<xsl:value-of  select="."/> <xsl:text>@@@</xsl:text>
	</xsl:template>

	<xsl:template match="Role">
			<xsl:value-of  select="."/> <xsl:text>
</xsl:text>
	</xsl:template>

	<xsl:template name="keysLang">
		<xsl:value-of  select="./Keys/Key[@Name='Country_English_influence']"/> <xsl:text>|</xsl:text>
		<xsl:value-of  select="./Keys/Key[@Name='Region_English_influence']"/> <xsl:text>|</xsl:text>
		<xsl:value-of  select="./Keys/Key[@Name='Months_English_practice']"/>
	</xsl:template>

	<xsl:template match="Title">
		<xsl:variable name="title" select="."/>
		<xsl:choose>
			<xsl:when test="matches($title, 'non')">
				<xsl:text>nonscenario|</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>scenario|</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="Location">
			<xsl:value-of  select="./Address"/> <xsl:text>|</xsl:text>
			<xsl:value-of  select="./Country"/> <xsl:text>|</xsl:text>
			<xsl:value-of  select="./Continent"/> <xsl:text>|</xsl:text>
	</xsl:template>
	
<!-- (meet_id, resource_id, uri, format, media, size, [source, src_nr, channel, speaker_id, start, end, page, date]) -->
<xsl:template match="MediaFile|WrittenResource">
<xsl:variable name="meetId" select="//Session/Name"/>
<xsl:text></xsl:text><xsl:value-of select="$meetId"/> <xsl:text>|</xsl:text>
<xsl:value-of select="@ResourceId"/> <xsl:text>|</xsl:text>
<xsl:value-of select="./ResourceLink"/> <xsl:text>|</xsl:text>

<xsl:choose>
	<xsl:when test="./Type">
		<xsl:value-of select="./Type"/><xsl:text>| </xsl:text>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="Keys/Key[@Name='Type']"/><xsl:text>|</xsl:text>
	</xsl:otherwise>
</xsl:choose>

<xsl:value-of select="./Format"/> <xsl:text>|</xsl:text>
<xsl:choose>
	<xsl:when test="./Size">
		<xsl:value-of select="./Size"/> <xsl:text>|</xsl:text>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="Keys/Key[@Name='Size']"/> <xsl:text>|</xsl:text>
	</xsl:otherwise>
</xsl:choose>
<xsl:value-of select="Keys/Key[@Name='Channel']"/> <xsl:text>|</xsl:text>
<xsl:value-of select="Keys/Key[@Name='Source']"/> <xsl:text>|</xsl:text>
<xsl:value-of select="Keys/Key[@Name='Source_Nr']"/> <xsl:text>|</xsl:text>
<xsl:value-of select="Keys/Key[@Name='Page_Nr']"/> <xsl:text>|</xsl:text>
<xsl:value-of select="Keys/Key[@Name='Date']"/> <xsl:text>
</xsl:text>
</xsl:template>

	<xsl:template match="*">
	</xsl:template>	
	
</xsl:stylesheet>
