#!/usr/bin/perl -w
#===============================================================================
# Description : this script is the starting point of the pipeline to generate a
# metadata database and be used to (1) crawling the MMM server and generate .imdi
# files, (2) to create .csv files from existing imdi corpus that can then be
# loaded to a db with the distributed sql script mdDb_loader.sql, (3) to execute both
# Mandatory parameters for: (1) -u: url to crawl for media information, -s: path to saxon
# -n: path to annotation files, -i: crawl + generate .imdi
#               (2) -o: path to imdi corpus, -d: generate .csv, -s: path to saxon
#               (3) -a: generate imdi corpus + csv files, -s: path to saxon,
# -u: url to crawl for media information, -n: path to annotation files
# Remarks: this script was developed to crawl a specific *private* URL, so it's
#           not coded within the script; not tested under unix;
#         --> path to annotations should be unix like
# Usage example: perl processMD.pl -u http://url/ -n  D:/annotations/ -s c:\saxon -a
# Author: Paula.Estrella@issco.unige.ch - ISSCO/ETI/UniGe
# Date: May 2007
#===============================================================================
use strict ;
$|=1;
# parameters  output  url   annota  imdi   db     all      help   saxon
use vars qw ($opt_o $opt_u $opt_n $opt_i $opt_d $opt_a $opt_h $opt_s);
use Getopt::Std;
getopts ('o:u:n:s:idha');

my $usage = "USAGE three options:\n(1) crawling the MMM server and generate .imdi files,
(2) to create .csv files from existing imdi corpus that can then be loaded to a db with the distributed sql script mdDb_loader.sql,
(3) to execute both\n
Mandatory parameters for: \n (1) -u: url to crawl for media information, -s: path to saxon
 -n: path to annotation files, -i: crawl + generate .imdi
               \n (2) -o: path to imdi corpus, -d: generate .csv, -s: path to saxon
               \n (3) -a: generate imdi corpus + csv files, -s: path to saxon,
 -u: url to crawl for media information, -n: path to annotation files";
die $usage if defined($opt_h);
die "[processMD.pl] Missing: url for crawling not specified" unless (defined $opt_d || defined $opt_u);
die "[processMD.pl] Missing: path to annotation files not specified" unless (defined $opt_d || defined $opt_n) ;
die "[processMD.pl] Missing: path to saxon not specified" unless defined $opt_s;

my $saxon = !($opt_s=~/[\/|\\]$/)?$opt_s."/":$opt_s;
die "[processMD.pl] Saxon processor not found\n" unless (-e $saxon);

my $pathAnnot = !($opt_n=~/[\/|\\]$/)?$opt_n."/":$opt_n;
$pathAnnot=~s/\\/\//g;
die "[processMD.pl] Annotations root folder not found\n" unless (-e $pathAnnot);

my $log = "outCrawler.xml";
my $participants =$pathAnnot."corpusResources/participants.xml";
die "[processMD.pl] participants.xml not found\n" unless (-e $participants);

my $meetings=$pathAnnot."corpusResources/meetings.xml";
die "[processMD.pl] meetings.xml not found\n" unless (-e $meetings);

my $url=$opt_u;
my $outputDir = ".";
(defined $opt_o)?$outputDir=$opt_o: print "NOTICE: Using current directory for output files";
$outputDir= !($outputDir=~/[\/|\\]$/)?"$outputDir/":$outputDir;
die "Output directory $outputDir not found\n" unless (-e $outputDir);
#
my $xslt ="ami2imdi.xslt";
my $stdout="";
my $command="";

if(defined $opt_i || defined $opt_a){
  $command = "perl crawler.pl $outputDir$log $url";
  $stdout = `$command`;
  if($stdout=~/ERROR/i || $stdout=~/missing/i){
    die "[processMD.pl] ".$stdout;

  }
  $outputDir=~s/\\/\//g;
  
  $command = "java -jar $saxon"."saxon8.jar $meetings $xslt logFile=\"$outputDir$log\" partFile=\"$participants\"
              outputDir=\"$outputDir\"";
  $stdout=`$command`;

  if($stdout=~/ERROR/i || $stdout=~/missing/i){
    die "[processMD.pl] ".$stdout;
  }
}

if(defined $opt_d || defined $opt_a){
  #db
  $command="perl xml2db.pl -s $saxon -i $outputDir -o $outputDir";
  $stdout=`$command`;

  if($stdout=~/Error/i || $stdout=~/missing/i){
    die "[processMD.pl] ".$stdout;
  }

}
