#!/usr/bin/perl -w
use strict ;
#===============================================================================
# Description : this script converts the metadata in .imdi format into .csv
# files, it can be used as a standalone script or can be called using processMD.pl
# Mandatory parameters are -s to indicate the path to the saxon processor (saxon8.jar)
# and -i to indicate the path to the .imdi files. Optional parameters are -h for
# help and -x to indicate the stylesheet to use, by default it will try to use
# imdi2db.xsl in the current directory
# Remarks: script not tested on unix/linux/solaris; some problems might arise with
# paths due to \ or /
# Usage example:  perl xml2db.pl -i D:\ami-im2-corpus -s C:\saxon
# URL : http://www.im2.ch/intranet/ips/wiki/DMAMetadataFilesAndDatabase
# Author: Paula Estrella - ISSCO/ETI/UniGe
# Date: May 2007
#===============================================================================

#            imdi    xslt  help   saxon   outDir
use vars qw ($opt_i $opt_x $opt_h $opt_s $opt_o);
use Getopt::Std;
getopts ('i:x:s:o:h');

my $usage = "USAGE: perl xml2db.pl -s <saxon root folder> -i <imdi root folder> [-x <stylesheet> -h]";

die $usage if defined($opt_h);
die "[xml2db.pl] Missing: folder with imdi files not specified" unless defined $opt_i;
die "[xml2db.pl] Missing: path to saxon not specified" unless defined $opt_s;

my $saxon=!($opt_s=~/[\/|\\]$/)?$opt_s."/saxon8.jar":$opt_s."saxon8.jar";
die "[xml2db.pl] Error: Saxon processor not found -- $saxon\n" unless (-e $saxon);

my $root = ($opt_i=~/[\/|\\]$/)?substr($opt_i, 0, -1):$opt_i;
die "[xml2db.pl] Error: Imdi files folder not found\n" unless (-e $root);

my $xslt = (defined $opt_x)?$opt_x:"imdi2db.xslt";
die "[xml2db.pl] Error: stylesheet imdi2db.xslt not found\n" unless (-e $xslt);

my $outDir = (defined $opt_o)?$opt_o:".";
$outDir= !($outDir=~/[\/|\\]$/)?$outDir."/":$outDir;

open(MEET, ">$outDir"."meetings.csv") or die "[xml2db.pl] Error: Couldn't create meetings.csv - $!";
open(PARTIC, ">$outDir"."participation.csv") or die "[xml2db.pl] Error: Couldn't create participation.csv - $!";
open(SPEAK, ">$outDir"."speakers.csv") or die "[xml2db.pl] Error: Couldn't create speakers.csv - $!";
open(INFLU, ">$outDir"."influence.csv") or die "[xml2db.pl] Error: Couldn't create influence.csv - $!";
open(REC, ">$outDir"."resources.csv") or die "[xml2db.pl] Error: Couldn't create resources.csv - $!";

my @filelist = glob("$root\\?*.imdi") ;

my $buffer;
my @lines;

foreach my $file (@filelist) {
	$buffer = `java -jar $saxon $file $xslt` ;
  if(!($buffer eq "")){
    @lines=split("@@@",$buffer);
  	print MEET $lines[0]."\n" ;

    &table(*PARTIC, $lines[1],"\n");
    &table(*SPEAK, $lines[2],"\n");
    if(!($lines[3]=~/NO/)){
      &table(*INFLU, $lines[3],"\n");
    }
    &table(*REC, $lines[4],"\n");
    print "$file\n";
  }
}

close MEET;
close PARTIC;
close INFLU;
close SPEAK;
close REC;
print STDOUT "Done.\n";
###############################################

sub table{
my ($handle)=shift;
my ($line)= shift ;
my $delimiter = shift;

  my @aux=split($delimiter,$line);
    foreach my $item (@aux){
      print $handle $item."\n";
  }
}
